package com.meas.system.service;

import java.util.List;

import com.meas.system.domain.MeasThermalImagerTestData;

/**
 * 热像仪测试数据Service接口
 *
 * @author wgk
 * @date 2024-06-13
 */
public interface IMeasThermalImagerTestDataService {
    /**
     * 查询热像仪测试数据
     *
     * @param id 热像仪测试数据主键
     * @return 热像仪测试数据
     */
    public MeasThermalImagerTestData selectMeasThermalImagerTestDataById(Long id);

    /**
     * 查询热像仪测试数据列表
     *
     * @param measThermalImagerTestData 热像仪测试数据
     * @return 热像仪测试数据集合
     */
    public List<MeasThermalImagerTestData> selectMeasThermalImagerTestDataList(MeasThermalImagerTestData measThermalImagerTestData);

    /**
     * 新增热像仪测试数据
     *
     * @param measThermalImagerTestData 热像仪测试数据
     * @return 结果
     */
    public MeasThermalImagerTestData insertMeasThermalImagerTestData(MeasThermalImagerTestData measThermalImagerTestData);

    /**
     * 修改热像仪测试数据
     *
     * @param measThermalImagerTestData 热像仪测试数据
     * @return 结果
     */
    public int updateMeasThermalImagerTestData(MeasThermalImagerTestData measThermalImagerTestData);

    /**
     * 批量删除热像仪测试数据
     *
     * @param ids 需要删除的热像仪测试数据主键集合
     * @return 结果
     */
    public int deleteMeasThermalImagerTestDataByIds(Long[] ids);

    /**
     * 删除热像仪测试数据信息
     *
     * @param id 热像仪测试数据主键
     * @return 结果
     */
    public int deleteMeasThermalImagerTestDataById(Long id);

    MeasThermalImagerTestData selectResultsByEnvDataId(Long envDataId);
}
